
proc setup_gui { record_list } {

	add_main_window_to_gui "Auto Optimization - Table"

	set row 1

        add_motor_to_gui $row $record_list "tz" "Table (vertical)"

	incr row

	add_motor_to_gui $row $record_list "ty" "Table (horizontal)"

	incr row

	add_motor_to_gui $row $record_list "tpitch" "Table (pitch)"

        incr row
	
	add_motor_to_gui $row $record_list "tyaw" "Table (yaw)"

        incr row

	add_buttons_to_gui

	wm deiconify .
}

proc main { record_list } {

	log_puts "Moving vertical slit size to 350 um."

	move_motor $record_list "bv_size" 350.0

	log_puts "Moving horizontal slit size to 350 um."

	move_motor $record_list "bh_size" 350.0
        
	log_puts "Removing all filters."

        move_motor $record_list "filter1" 0.0

        move_motor $record_list "filter2" 0.0

	log_puts "Removing all half slits."

	remove_halfslit $record_list "us_vert"
	remove_halfslit $record_list "us_horiz"
	remove_halfslit $record_list "ds_vert"
	remove_halfslit $record_list "ds_horiz"

	log_puts "Performing table vertical scan."

	log_puts "Inserting upstream vertical half slit."

	insert_halfslit $record_list "us_vert"

	log_puts "Starting 'tz' optimization scan."

	optimize_to_edge $record_list "tz"

	log_puts "Removing upstream vertical half slit."

	remove_halfslit $record_list "us_vert"

	log_puts "*** Table vertical optimization complete. ***"

	log_puts "Performing table horizontal scan."

	log_puts "Inserting upstream horizontal half slit."

        insert_halfslit $record_list "us_horiz"

        log_puts "Starting 'ty' optimization scan."

        optimize_to_edge $record_list "ty"

        log_puts "Removing upstream horizontal half slit."

        remove_halfslit $record_list "us_horiz"

	log_puts "*** Table horizontal optimization complete. ***"

	log_puts "Performing table pitch optimizatiom."
 
	log_puts "Inserting downstream vertical half slit."

        insert_halfslit $record_list "ds_vert"

        log_puts "Starting 'tpitch' optimization scan."

        optimize_to_edge $record_list "tpitch"

        log_puts "Removing downstream vertical half slit."

        remove_halfslit $record_list "ds_vert"

        log_puts "*** Table pitch optimization complete. ***"

	log_puts "Performing table yaw optimizationi."

	log_puts "Inserting downstream horizontal half slit."

        insert_halfslit $record_list "ds_horiz"

        log_puts "Starting 'tyaw' optimization scan."

        optimize_to_edge $record_list "tyaw"

        log_puts "Removing downstream horizontal half slit."

        remove_halfslit $record_list "ds_horiz"

	log_puts "*** Table yaw optimization complete. ***"

	log_puts "Moving slit sizes to 200 by 200 um."

        move_motor $record_list "bv_size" 200.0

        move_motor $record_list "bh_size" 200.0

	return
}

proc insert_halfslit { record_list slit_name } {

	set slit [ $record_list get_record $slit_name ]

	$slit relay_command 1
}

proc remove_halfslit { record_list slit_name } {

	set slit [ $record_list get_record $slit_name ]

	$slit relay_command 0
}

